pathToArchive property
The path to an archive file (which may or may not exist)
It should only point to a file. When used with export, the file does not have to exist. Otherwise, it should exist.
Important
The path must be accessible to the application. For example, on Android devices, it should not be in external storage, unless the app has the appropriate (dangerous) permissions.
On mobile platforms (/those platforms which operate sandboxed storage), if the app does not have external storage permissions, it is recommended to set this path to a path the application can definitely control (such as app support), using a path from 'package:path_provider', then share it somewhere else using the system flow (using 'package:share_plus').
Implementation
final String pathToArchive;