RootExternal class
Export & import 'archives' of selected stores and tiles, outside of the FMTC environment
Archives are backend specific. They cannot be imported by a backend different to the one that exported it.
Archives are only readable by FMTC. The archive may hold a similar form to the raw format of the database used by the backend, but FMTC-specific information has been attached, and therefore the file will be unreadable by non-FMTC database implementations.
Archives are potentially backend/FMTC version specific, dependent on whether the database schema was changed. An archive created on an older schema is usually importable into a newer schema, but this is not guaranteed. An archive created in a newer schema cannot be imported into an older schema. Note that this is not enforced by the archive format, and the schema may not change between FMTC or backend version changes.
Importing (especially) and exporting operations are likely to be slow. It is not recommended to attempt to use other FMTC operations during the operation, to avoid slowing it further or potentially causing inconsistent state.
Importing and exporting operations may consume more storage capacity than expected, especially temporarily during the operation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
listStores
→ Future<
List< String> > -
List the available store names within the archive at pathToArchive
no setter
- pathToArchive → String
-
The path to an archive file (which may or may not exist)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
export(
{required List< String> storeNames}) → Future<int> - Creates an archive at pathToArchive containing the specified stores and their tiles
-
import(
{List< String> ? storeNames, ImportConflictStrategy strategy = ImportConflictStrategy.rename}) → ImportResult - Imports specified stores and all necessary tiles into the current root from pathToArchive
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited